@@ -7,7 +7,6 @@ __author__ = 'Zitong Lu'
 import numpy as np
 from neurora.rdm_cal import bhvRDM
 from neurora.rdm_cal import eegRDM
-from neurora.rdm_cal import ecogRDM
 from neurora.rdm_cal import fmriRDM
 from neurora.rdm_corr import rdm_correlation_spearman
 from neurora.rdm_corr import rdm_correlation_pearson
@@ -327,162 +326,6 @@ def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, chl_opt=0, time_opt=0, time_wi
     return corr
 
 
-' a function for calculating the Similarity/Correlation Cosfficient between behavioral data and sEEG/ECoG/eletricophysiological data'
-
-def bhvANDecog_corr(bhv_data, ele_data, time_win=5, time_step=5, ecog_opt="allin", method="spearman", fisherz=False, rescale=False, permutation=False, iter=5000):
-
-    """
-    Calculate the Similarities between behavioral data and sEEG/ECoG/eletricophysiological data
-
-    Parameters
-    ----------
-    bhv_data : array
-        The behavioral data.
-        The shape of bhv_data must be [n_cons, n_trials].
-        n_cons, n_subs & n_trials represent the number of conidtions, the number of subjects & the number of trials,
-        respectively.
-    ele_data : array
-        The ECoG/sEEG/electrophysiology data.
-        The shape of EEGdata must be [n_cons, n_trials, n_chls, n_ts].
-        n_cons, n_trials, n_chls & n_ts represent the number of conidtions, the number of trials,
-        the number of channels & the number of time-points, respectively.
-    time_win : int. Default is 5.
-        Set a time-window for calculating the RDM & similarities for different time-points.
-        Only when time_opt=1, time_win works.
-        If time_win=5, that means each calculation process based on 5 time-points.
-    time_step : int. Default is 5.
-        The time step size for each time of calculating.
-        Only when time_opt=1, time_step works.
-    ecog_opt : string 'channel', 'time' or 'all'. Default is 'all'.
-        Calculate the RDM for each channel or for each time-point or for the whole data.
-        If ecog_opt='channel', return n_chls RDMs based on each channel's data.
-        If ecog_opt='time', return int((n_ts-time_win)/time_step)+1 RDMs based on each time-point's data respectively.
-        If ecog_opt='allin', return only one RDM based on all data.
-    method : string 'spearman' or 'pearson' or 'kendall' or 'similarity' or 'distance'. Default is 'spearman'.
-        The method to calculate the similarities.
-        If method='spearman', calculate the Spearman Correlations. If method='pearson', calculate the Pearson
-        Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
-        Cosine Similarities. If method='distance', calculate the Euclidean Distances.
-    fisherz : bool True or False. Default is False.
-        Do the Fisher-Z transform of the RDMs or not.
-    rescale : bool True or False.
-        Rescale the values in RDM or not.
-        Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagonal.
-    permutation : bool True or False. Default is False.
-        Use permutation test or not.
-    iter : int. Default is 5000.
-        The times for iteration.
-
-    Returns
-    -------
-    corrs : array
-        The similarities between behavioral data and ECoG/sEEG/electrophysiology.
-        If opt='channel', return n_chls corrs result.
-            The shape of corrs is [n_chls, 2]. 2 represents a r-value and a p-value. If method='similarity' or
-            method='distance', the p-values are all 0.
-        If opt='time', return int(n_ts/time_win) corrs result.
-            The shape of corrs is [int((n_ts-time_win)/time_step)+1, 2]. 2 represents a r-value and a p-value. If
-            method='similarity' or method='distance', the p-values are all 0.
-        If opt='all', return one corr result.
-            The shape of corrs is [2], a r-value and a p-value. If method='similarity' or method='distance',
-            the p-value is 0.
-    """
-
-    # sub_opt = 1, bhv_data here belongs to one subject, and its shape must be : [cons, trials]
-
-    # get the number of conditions & the number of trials
-    cons, trials = np.shape(bhv_data)
-
-    # shape of bhv_data: [cons, trials] -> [cons, subs, trials] & subs=1
-    bhv_data = np.reshape(bhv_data, [cons, 1, trials])
-
-    # calculate bhv_rdm
-    bhv_rdm = bhvRDM(bhv_data)
-
-
-    # ecog_opt='channel'
-
-    if ecog_opt == "channel":
-
-        # calculate the ecog_rdms
-        ecog_rdms = ecogRDM(ele_data, opt="channel")
-
-        # get the number of channels
-        chls_num = np.shape(ele_data)[2]
-
-        # initialize the corrs
-        corrs = np.zeros([chls_num, 2], dtype=np.float64)
-
-        # get the corrs
-        for i in range(chls_num):
-
-            if method == "spearman":
-                corrs[i] = rdm_correlation_spearman(bhv_rdm, ecog_rdms[i], fisherz=fisherz, rescale=rescale, permutation=permutation, iter=iter)
-            elif method == "pearson":
-                corrs[i] = rdm_correlation_pearson(bhv_rdm, ecog_rdms[i], fisherz=fisherz, rescale=rescale, permutation=permutation, iter=iter)
-            elif method == "kendall":
-                corrs[i] = rdm_correlation_kendall(bhv_rdm, ecog_rdms[i], fisherz=fisherz, rescale=rescale, permutation=permutation, iter=iter)
-            elif method == "similarity":
-                corrs[i, 0] = rdm_similarity(bhv_rdm, ecog_rdms[i], rescale=rescale)
-            elif method == "distance":
-                corrs[i, 0] = rdm_distance(bhv_rdm, ecog_rdms[i], rescale=rescale)
-
-        return corrs
-
-    # ecog_opt='time'
-
-    elif ecog_opt == "time":
-
-        # calculate the ecog_rdms
-        ecog_rdms = ecogRDM(ele_data, time_win=time_win, time_step=time_step, opt="time")
-
-        # get the number of time-points for calculating
-        ts = np.shape(ele_data)[3]
-        ts = int((ts-time_win)/time_step)+1
-
-        # initialize the corrs
-        corrs = np.zeros([ts, 2], dtype=np.float64)
-
-        # calculate the corrs
-        for i in range(ts):
-
-            if method == "spearman":
-                corrs[i] = rdm_correlation_spearman(bhv_rdm, ecog_rdms[i], fisherz=fisherz, rescale=rescale, permutation=permutation, iter=iter)
-            elif method == "pearson":
-                corrs[i] = rdm_correlation_pearson(bhv_rdm, ecog_rdms[i], fisherz=fisherz, rescale=rescale, permutation=permutation, iter=iter)
-            elif method == "kendall":
-                corrs[i] = rdm_correlation_kendall(bhv_rdm, ecog_rdms[i], fisherz=fisherz, rescale=rescale, permutation=permutation, iter=iter)
-            elif method == "similarity":
-                corrs[i, 0] = rdm_similarity(bhv_rdm, ecog_rdms[i], rescale=rescale)
-            elif method == "distance":
-                corrs[i, 0] = rdm_distance(bhv_rdm, ecog_rdms[i], rescale=rescale)
-
-        return corrs
-
-    # ecog_opt="allin"
-
-    # calculate the ecog_rdm
-    ecog_rdm = ecogRDM(ele_data, opt="allin")
-
-    # initialize the corr
-    corr = np.zeros([2], dtype=np.float64)
-
-    # calculate the corr
-    if method == "spearman":
-        corr = rdm_correlation_spearman(bhv_rdm, ecog_rdm, fisherz=fisherz, rescale=rescale, permutation=permutation, iter=iter)
-    elif method == "pearson":
-        corr = rdm_correlation_pearson(bhv_rdm, ecog_rdm, fisherz=fisherz, rescale=rescale, permutation=permutation, iter=iter)
-    elif method == "kendall":
-        corr = rdm_correlation_kendall(bhv_rdm, ecog_rdm, fisherz=fisherz, rescale=rescale, permutation=permutation, iter=iter)
-    elif method == "similarity":
-        corr[0] = rdm_similarity(bhv_rdm, ecog_rdm, rescale=rescale)
-    elif method == "distance":
-        corr[0] = rdm_distance(bhv_rdm, ecog_rdm, rescale=rescale)
-
-    return corr
-
-
 ' a function for calculating the Similarity/Correlation Cosfficient between behavioral data and fMRI data (searchlight) '
 
 def bhvANDfmri_corr(bhv_data, fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_result=1, method="spearman", fisherz=False, rescale=False, permutation=False, iter=5000):
@@ -502,7 +345,8 @@ def bhvANDfmri_corr(bhv_data, fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub
         The shape of fmri_data must be [n_cons, n_subs, nx, ny, nz]. n_cons, nx, ny, nz represent the number of
         conditions, the number of subs & the size of fMRI-img, respectively.
     ksize : array or list [kx, ky, kz]. Default is [3, 3, 3].
-        The size of the fMRI-img. nx, ny, nz represent the number of voxels along the x, y, z axis.
+        The size of the calculation unit for searchlight.
+        kx, ky, kz represent the number of voxels along the x, y, z axis.
     strides : array or list [sx, sy, sz]. Default is [1, 1, 1].
         The strides for calculating along the x, y, z axis.
     sub_result: int 0 or 1. Default is 1.
@@ -648,7 +492,8 @@ def eegANDfmri_corr(eeg_data, fmri_data, chl_opt=0, ksize=[3, 3, 3], strides=[1,
         If chl_opt=0, calculating based on all channels' data.
         If chl_opt=1, calculating based on each channel's data respectively.
     ksize : array or list [kx, ky, kz]. Default is [3, 3, 3].
-        The size of the fMRI-img. nx, ny, nz represent the number of voxels along the x, y, z axis.
+        The size of the calculation unit for searchlight.
+        kx, ky, kz represent the number of voxels along the x, y, z axis.
     strides : array or list [sx, sy, sz]. Default is [1, 1, 1].
         The strides for calculating along the x, y, z axis.
     sub_result: int 0 or 1. Default is 1.
